@@ -23,13 +23,20 @@
   }  
   
   Pedig <- prePed(Pedig, addNum=TRUE, keep=c(from, to))
+  Pedig$nOff <- 0
+  x <- table(Pedig$Sire)
+  Pedig[names(x),"nOff"] <- x
+  x <- table(Pedig$Dam)
+  Pedig[names(x),"nOff"] <- x
+  
   from  <- Pedig$Indiv[Pedig$Indiv %in% from] 
   to    <- Pedig$Indiv[Pedig$Indiv %in% to]
-  numAnc   <- match(from, Pedig$Indiv)
-  rNames   <- as.character(Pedig$Indiv)
-  cNames   <- from
-  
-  GeneCont <- rcpp_genecont(as.integer(Pedig$numSire), as.integer(Pedig$numDam), as.integer(numAnc-1), rNames, cNames)
+  numAnc  <- match(from, Pedig$Indiv)
+  numKeep <- match(to,   Pedig$Indiv)
+  rNames  <- as.character(Pedig$Indiv[Pedig$Indiv %in% to])
+  cNames  <- from
+
+  GeneCont <- rcpp_genecont(as.integer(Pedig$numSire), as.integer(Pedig$numDam), as.integer(numAnc-1), as.integer(numKeep-1), as.integer(Pedig$Indiv %in% to), rNames, cNames, as.integer(Pedig$nOff))
   if(identical(rNames, to)){return(GeneCont)}
   GeneCont[to, from, drop=FALSE]
 }
