@@ -18,6 +18,7 @@ extern SEXP optiSel_rcpp_segIBDandN(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SE
 extern SEXP optiSel_rcpp_segIBDandNVersion2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP optiSel_rcpp_segInbreeding(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP optiSel_rcpp_segN(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP optiSel_rcpp_genecont(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP optiSel_rcpp_makeA(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP optiSel_rcpp_makeA_lowMem(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
@@ -31,6 +32,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"optiSel_rcpp_segIBDandNVersion2", (DL_FUNC) &optiSel_rcpp_segIBDandNVersion2, 13},
     {"optiSel_rcpp_segInbreeding",      (DL_FUNC) &optiSel_rcpp_segInbreeding,      17},
     {"optiSel_rcpp_segN",               (DL_FUNC) &optiSel_rcpp_segN,                5},
+    {"optiSel_rcpp_genecont",           (DL_FUNC) &optiSel_rcpp_genecont,            8},
     {"optiSel_rcpp_makeA",              (DL_FUNC) &optiSel_rcpp_makeA,               5},
     {"optiSel_rcpp_makeA_lowMem",       (DL_FUNC) &optiSel_rcpp_makeA_lowMem,        8},
     {NULL, NULL, 0}
